@@ -14,7 +14,7 @@ def all_file(root, patterns='*.pyc', ignore_dirs=[], \
     for path, subdirs, files in os.walk(root):
         ig = False
         for ignore_dir in ignore_dirs:
-            if path.startswith(ignore_dir)
+            if path.startswith(ignore_dir):
                 ig = True
                 break
         if ig:
